lilypondparsertools.LilyPondFraction
====================================

.. inheritance-diagram:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction
   :private-bases:

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lilypondparsertools.LilyPondFraction.LilyPondFraction.LilyPondFraction.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
